<?php
define('KIDZY_NAME', wp_get_theme()->get( 'Name' ));
define('KIDZY_CSS', get_template_directory_uri().'/css/');
define('KIDZY_JS', get_template_directory_uri().'/js/');

add_filter('use_block_editor_for_post', '__return_false');

/*-----------------------------------------------------
 * 				KIDZY Options
*----------------------------------------------------*/
if(!function_exists('kidzy_options')):
	function kidzy_options($arg) {
		global $themeum_options;
		if (isset($themeum_options[$arg])) {
			return $themeum_options[$arg];
		} else {
			return false;
		}
	}
endif;

if(!function_exists('kidzy_options_url')):
	function kidzy_options_url($arg,$arg2) {
		global $themeum_options;
		if (isset($themeum_options[$arg][$arg2])) {
			return $themeum_options[$arg][$arg2];
		} else {
			return false;
		}
	}
endif;


/*-------------------------------------------*
 *				Register Navigation
 *------------------------------------------*/
register_nav_menus( array(
	'primary' 	=> esc_html__( 'Primary Menu', 'kidzy' )
) );

/*-------------------------------------------*
 *				title tag
 *------------------------------------------*/
/*Used only here*/

add_action( 'after_setup_theme', 'kidzy_slug_setup' );
if(!function_exists( 'kidzy_slug_setup' )):
    function kidzy_slug_setup() {
        add_theme_support( 'title-tag' );
        add_theme_support( 'post-formats', array('image','video','quote','link','gallery','audio'));
    }
endif;

/*-------------------------------------------*
 *				Navwalker
 *------------------------------------------*/
require_once( get_template_directory()  . '/lib/menu/admin-megamenu-walker.php');
require_once( get_template_directory()  . '/lib/menu/meagmenu-walker.php');
require_once( get_template_directory()  . '/lib/menu/mobile-navwalker.php');
add_filter( 'wp_edit_nav_menu_walker', function( $class, $menu_id ){
	return 'Themeum_Megamenu_Walker';
}, 10, 2 );


/*-------------------------------------------*
 *				Kidzy Register
 *------------------------------------------*/
require_once( get_template_directory()  . '/lib/main-function/themeum-register.php');


/*-------------------------------------------------------
 *			Themeum Core
 *-------------------------------------------------------*/
require_once( get_template_directory()  . '/lib/main-function/themeum-core.php');


/*-----------------------------------------------------
 * 				Custom Excerpt Length
 *----------------------------------------------------*/

if(!function_exists('kidzy_excerpt_max_charlength')):
	function kidzy_excerpt_max_charlength($charlength) {
		$excerpt = get_the_excerpt();
		$charlength++;

		if ( mb_strlen( $excerpt ) > $charlength ) {
			$subex = mb_substr( $excerpt, 0, $charlength - 5 );
			$exwords = explode( ' ', $subex );
			$excut = - ( mb_strlen( $exwords[ count( $exwords ) - 1 ] ) );
			if ( $excut < 0 ) {
				return mb_substr( $subex, 0, $excut );
			} else {
				return $subex;
			}

		} else {
			return $excerpt;
		}
	}
endif;


/*-----------------------------------------------------
 * 				Custom body class
 *----------------------------------------------------*/
add_filter( 'body_class', 'kidzy_body_class' );
function kidzy_body_class( $classes ) {
     $menu_style = 'none';
     
    if ( kidzy_options('boxfull-en') ) {
    	$layout = esc_attr(kidzy_options('boxfull-en'));
    }else{
    	$layout = 'fullwidth';
    }

     $classes[] = $layout.'-bg'; 
	return $classes;
}


/*-------------------------------------------------------
 *			Themeum Pagination
 *-------------------------------------------------------*/

if(!function_exists('themeum_pagination')):

	function themeum_pagination($pages = '', $range = 2)
	{  
	     $showitems = ($range * 1)+1;  

	     global $paged;

	     if(empty($paged)) $paged = 1;

	     if($pages == '')
	     {
	         global $wp_query;
	         $pages = $wp_query->max_num_pages;

	         if(!$pages)
	         {
	             $pages = 1;
	         }
	     }   

	     if(1 != $pages)
	     {
			echo "<div class='row'><div class='col-sm-12 col-xs-12 text-center'><ul class='pagination'>";

			if($paged > 2 && $paged > $range+1 && $showitems < $pages){
				echo "<li><a href='".get_pagenum_link(1)."'>&laquo;</a></li>";
			}

			if($paged > 1 && $showitems < $pages){ 
				echo '<li>';
				previous_posts_link(esc_html__("Previous","kidzy"));
				echo '</li>';
			}

			for ($i=1; $i <= $pages; $i++)
			{
				if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
				{
					echo ($paged == $i)? "<li class='active'><a href='#'>".$i."</a></li>":"<li><a href='".get_pagenum_link($i)."' >".$i."</a></li>";
				}
			}

			if ($paged < $pages && $showitems < $pages){
				echo '<li>';
				next_posts_link(esc_html__("Next","kidzy"));
				echo '</li>';
			}

			if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages){
				echo "<li><a href='".get_pagenum_link($pages)."'>&raquo;</a></li>";
			}
			
			echo "</ul></div></div>";
	     }
	}

endif;


/*-------------------------------------------------------
*			Custom Widgets Include
*-------------------------------------------------------*/
// all custom widgets
require_once( get_template_directory()  . '/lib/widgets/themeum_about_widget.php');
require_once( get_template_directory()  . '/lib/widgets/popular-post.php');
require_once( get_template_directory()  . '/lib/widgets/class-list-widget.php');


/*-------------------------------------------*
 *				woocommerce support
 *------------------------------------------*/
add_action( 'after_setup_theme', 'kidzy_woocommerce_support' );
function kidzy_woocommerce_support() {
    add_theme_support( 'woocommerce' );
}


/*-----------------------------------------------------
 * 				Custom body class
 *----------------------------------------------------*/
add_filter( 'body_class', 'kidzy_body_classs' );
function kidzy_body_classs( $classes ) {
     $menu_style = 'none';
     if ( kidzy_options('boxfull-en') ) {
      $layout = esc_attr(kidzy_options('boxfull-en'));
     }else{
        $layout = 'fullwidth';
     }
     $classes[] = $layout.'-bg'; 
	return $classes;
}
